# export.m - Result Export to Database Script
# Author:   Jamie McIntosh
# 
# Note: Requires 'logfile' which contains all the data
#

# Copyright 2009-2012  Richard James MacPherson, Grant Ingram, 
# Jamie McIntosh and Michael Hilfer.  
# This file is part of PEW V2.

# PEW is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# PEW is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with PEW.  If not, see <http://www.gnu.org/licenses/>.

#####################
# Revision History - Jamie McIntosh
# 1.00 - Creation Point
#
#####################
# Known Issues
#
#####################

function export()

## Global Parameters
global npar; global popsize; global cost_str; global iga;
global base_dir; global par;

## Database Settings
hl = 3; % Header lines

## Root of Database Structure
data_root = '/data/l4cfd/mcbxm15/pew/database/';
chdir(sprintf("%s",data_root));

## Establish Database Size
[status,output] = system('wc -l logfile'); % Work out number of lines in database
data_str = split(output," "); % Truncates filename from wc output
file_size = str2num(data_str(1,:));
data_size = file_size-hl;

## Read in ID and PAR matrices
fid = fopen("logfile",'a'); % Opens database to be written at end of file

count=0; % ID counter
for chrom=1:1:popsize
  if par(chrom,npar+1) != 1000 % Failed designs are not exported to the database
    ## ID
    fprintf(fid,"%d|",data_size+1+count);
    
    ## Date
    date=strftime("%d-%m-%y",localtime (time ()));
    fprintf(fid,"%s|",date);
    
    ## PAR Matrix
    for i=1:1:npar
      fprintf(fid,'%.3f ',par(chrom,i));
    endfor
    fprintf(fid,"|");

    ## Cost Function
    fprintf(fid,"%s|",cost_str);
    
    ## Cost
    fprintf(fid,"%.3f\n",par(chrom,npar+1));
  
    ## Copy Files to Database Store
     % Command Listing (DO NOT EDIT)
    sy1=sprintf("cp %sGeneration_%d/chr_%d/chrom.ip %sip/%d.ip",base_dir,iga,chrom,data_root,data_size+1+count);
    %sy2=sprintf("cp %sGeneration_%d/chr_%d/default_id.dbs %sgambit/%d.dbs",base_dir,iga,chrom,data_root,data_size+1+count);
    %sy3=sprintf("cp %sGeneration_%d/chr_%d/default_id.jou %sgambit/%d.jou",base_dir,iga,chrom,data_root,data_size+1+count);
    %sy4=sprintf("cp %sGeneration_%d/chr_%d/default_id.trn %sgambit/%d.trn",base_dir,iga,chrom,data_root,data_size+1+count);
    sy5=sprintf("cp %sGeneration_%d/chr_%d/base.cas %sfluent/%d.cas",base_dir,iga,chrom,data_root,data_size+1+count);
    sy6=sprintf("cp %sGeneration_%d/chr_%d/base.dat %sfluent/%d.dat",base_dir,iga,chrom,data_root,data_size+1+count);
    sy7=sprintf("cp %sGeneration_%d/chr_%d/case.msh %sfluent/%d.msh",base_dir,iga,chrom,data_root,data_size+1+count);
    sy8=sprintf("cp %sGeneration_%d/chr_%d/ref %sref/%d",base_dir,iga,chrom,data_root,data_size+1+count);
    sy9=sprintf("cp %sGeneration_%d/chr_%d/res %sres/%d",base_dir,iga,chrom,data_root,data_size+1+count);
    sy10=sprintf("cp %sGeneration_%d/chr_%d/result.are %sresult/%d.are",base_dir,iga,chrom,data_root,data_size+1+count);
    sy11=sprintf("cp %sGeneration_%d/chr_%d/result.avg %sresult/%d.avg",base_dir,iga,chrom,data_root,data_size+1+count);
    sy12=sprintf("cp %sGeneration_%d/chr_%d/result.fld %sresult/%d.fld",base_dir,iga,chrom,data_root,data_size+1+count);
    sy13=sprintf("cp %sGeneration_%d/chr_%d/result.fldrr %sresult/%d.fldrr",base_dir,iga,chrom,data_root,data_size+1+count);
    sy14=sprintf("cp %sGeneration_%d/chr_%d/result.t5c %sresult/%d.t5c",base_dir,iga,chrom,data_root,data_size+1+count);
    sy15=sprintf("cp %sGeneration_%d/chr_%d/result.txt %sresult/%d.txt",base_dir,iga,chrom,data_root,data_size+1+count);

     % Comment the commands below as required to save disk space
    system(sy1);  % ip file : COMPULSORY (DO NOT COMMENT)
%    %system(sy2);  % gambit files
%    %system(sy3);
%    %system(sy4);
%    system(sy5);  % fluent files
%    system(sy6);
%    system(sy7);
%    system(sy8);  % ref file
%    system(sy9);  % res file
%    system(sy10); % result files
%    system(sy11);
%    system(sy12);
%    system(sy13);
%    system(sy14);
%    system(sy15);

    count++;
  endif
endfor

fclose(fid);

chdir(sprintf("%s",base_dir)); % Return to base directory

endfunction
