# Copyright 2009-2012  Richard James MacPherson, Grant Ingram, 
# Jamie McIntosh and Michael Hilfer.  
# This file is part of PEW V2.

# PEW is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# PEW is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with PEW.  If not, see <http://www.gnu.org/licenses/>.

function stream = streamprocess()

## Import Stream Data
stream_data = dlmread('streamdata');  % of the form x,y,z,t,v (time, velocity)
stream_data(1:7,:) = [];  % remove the first 7 header lines

stream_cumulative = 0;  % initialise row data marker
stream_penalty = 0;     % initialise stream penalty
for stream_no = 1:1:100
  stream_length = stream_data(stream_cumulative+1,1); % determine number of data rows to process
  stream_current = []; % initialise stream data
  stream_current = stream_data(stream_cumulative+2:stream_cumulative+stream_length+1,:); % set current stream
  stream_cumulative = stream_cumulative+stream_length+1; % update row marker

  ## Determine Region of Interest
  lb = min(stream_current(:,1)); % determine whether data fits in interpolation range
  if lb < -0.243 % start of profiled region
    lb = -0.243; % data exists outside of range so start at beginning of profiling
  else
    lb = round(lb/0.001)*0.001; % round to 3dp
  endif

  ub = max(stream_current(:,1));
  if ub > 0.030 % end of profiled region
    ub = 0.030; % data exists outside of range so start at end of profiling
  else
    ub = round(ub/0.001)*0.001; % round to 3dp
  endif

  ## Calculation Parameters
  dx = 0.01;
  tol = -0.5;
  ## Check if Differential Dynamic Head is within Tolerance Levels
  for x1 = lb:dx:ub-dx % endwall limits
    x2 = x1 + dx;
   
    ## Interpolate Data Set
    p1 = interp1(stream_current(:,1),stream_current(:,5),x1,'linear','extrap');
    p2 = interp1(stream_current(:,1),stream_current(:,5),x2,'linear','extrap');

    ## Compute Separation Coefficient
    sep_coeff = (p1 - p2)/(0.5*1.179*19.1^2);

    ## Check for tolerance
    if sep_coeff < tol
      stream_penalty = stream_penalty + abs(sep_coeff);
    endif
  endfor
endfor
stream = stream_penalty;
